@@ -43,108 +43,108 @@ typedef struct  {
 StringMapping;
 
 CharMapping acute [] = {
-    {'A', ''},
-    {'E', ''},
-    {'I', ''},
-    {'O', ''},
-    {'U', ''},
-    {'Y', ''},
-    {'a', ''},
-    {'e', ''},
-    {'i', ''},
-    {'o', ''},
-    {'u', ''},
-    {'y', ''},
+    {'A', '\xC1'},
+    {'E', '\xC9'},
+    {'I', '\xCD'},
+    {'O', '\xD3'},
+    {'U', '\xDA'},
+    {'Y', '\xDD'},
+    {'a', '\xE1'},
+    {'e', '\xE9'},
+    {'i', '\xED'},
+    {'o', '\xF3'},
+    {'u', '\xFA'},
+    {'y', '\xFD'},
     {0, 0}
 };
 
 CharMapping grave [] = {
-    {'A', ''},
-    {'E', ''},
-    {'I', ''},
-    {'O', ''},
-    {'U', ''},
-    {'a', ''},
-    {'e', ''},
-    {'i', ''},
-    {'o', ''},
-    {'u', ''},
+    {'A', '\xC0'},
+    {'E', '\xC8'},
+    {'I', '\xCC'},
+    {'O', '\xD2'},
+    {'U', '\xD9'},
+    {'a', '\xE0'},
+    {'e', '\xE8'},
+    {'i', '\xEC'},
+    {'o', '\xF2'},
+    {'u', '\xF9'},
     {0, 0}
 };
 
 CharMapping hat [] = {
-    {'A', ''},
-    {'E', ''},
-    {'I', ''},
-    {'O', ''},
-    {'U', ''},
-    {'a', ''},
-    {'e', ''},
-    {'i', ''},
-    {'o', ''},
-    {'u', ''},
+    {'A', '\xC2'},
+    {'E', '\xCA'},
+    {'I', '\xCE'},
+    {'O', '\xD4'},
+    {'U', '\xDB'},
+    {'a', '\xE2'},
+    {'e', '\xEA'},
+    {'i', '\xEE'},
+    {'o', '\xF4'},
+    {'u', '\xFB'},
     {0, 0}
 };
 
 CharMapping trema [] = {
-    {'A', ''},
-    {'E', ''},
-    {'I', ''},
-    {'O', ''},
-    {'U', ''},
-    {'a', ''},
-    {'e', ''},
-    {'i', ''},
-    {'o', ''},
-    {'u', ''},
-    {'y', ''},
+    {'A', '\xC4'},
+    {'E', '\xCB'},
+    {'I', '\xCF'},
+    {'O', '\xD6'},
+    {'U', '\xDC'},
+    {'a', '\xE4'},
+    {'e', '\xEB'},
+    {'i', '\xEF'},
+    {'o', '\xF6'},
+    {'u', '\xFC'},
+    {'y', '\xFF'},
     {0, 0}
 };
 
 CharMapping cedilla [] = {
-    {'C', ''},
-    {'c', ''},
+    {'C', '\xC7'},
+    {'c', '\xE7'},
     {0, 0}
 };
 
 CharMapping tilda [] = {
-    {'A', ''},
-    {'O', ''},
-    {'a', ''},
-    {'o', ''},
-    {'n', ''},
-    {'N', ''},
+    {'A', '\xC3'},
+    {'O', '\xD5'},
+    {'a', '\xE3'},
+    {'o', '\xF5'},
+    {'n', '\xF1'},
+    {'N', '\xD1'},
     {0, 0}
 };
 
 StringMapping commands [] = {
     {"backslash", "\\"},
-    {"S",  ""},
-    {"ss", ""},
-    {"DH", ""},
-    {"dh", ""},
-    {"AE", ""},
-    {"ae", ""},
-    {"O",  ""},
-    {"o",  ""},
-    {"TH", ""},
-    {"th", ""},
-    {"aa", ""},
-    {"AA", ""},
-    {"guillemotleft",    ""},
-    {"guillemotright",   ""},
-    {"flqq",             ""},
-    {"frqq",             ""},
+    {"S",  "\xA7"},
+    {"ss", "\xDF"},
+    {"DH", "\xD0"},
+    {"dh", "\xF0"},
+    {"AE", "\xC6"},
+    {"ae", "\xE6"},
+    {"O",  "\xD8"},
+    {"o",  "\xF8"},
+    {"TH", "\xDE"},
+    {"th", "\xFE"},
+    {"aa", "\xE5"},
+    {"AA", "\xC5"},
+    {"guillemotleft",    "\xAB"},
+    {"guillemotright",   "\xBB"},
+    {"flqq",             "\xAB"},
+    {"frqq",             "\xBB"},
     {"guilsingleft",     "<"},
     {"guilsingright",    ">"},
-    {"textquestiondown", ""},
-    {"textexclamdown",   ""},
-    {"copyright",        ""},
-    {"pound",            ""},
-    {"neg",              ""},
-    {"-",                ""},
-    {"cdotp",            ""},
-    {",",                ""},
+    {"textquestiondown", "\xBF"},
+    {"textexclamdown",   "\xA1"},
+    {"copyright",        "\xA9"},
+    {"pound",            "\xA3"},
+    {"neg",              "\xAC"},
+    {"-",                "\xAD"},
+    {"cdotp",            "\xB7"},
+    {",",                "\xB8"},
     {NULL, NULL}
 };
 
@@ -340,7 +340,8 @@ bibtex_capitalize (gchar * text,
 
     /* Put everything lowercase */
     if (is_noun) {
-	g_strdown (text);
+	gchar* c = text;
+	for (; *c != '\0'; *c = g_ascii_tolower(*c), c++);
     }
 
     current = text;
