@@ -108,11 +108,10 @@ bibtex_source_set_string (BibtexSource * source,
     g_return_if_fail (key != NULL);
 
     if ((oldstruct = g_hash_table_lookup (source->table, inskey)) == NULL) {
-	inskey = g_strdup (key);
-	g_strdown (inskey);
+	inskey = g_ascii_strdown(key, -1);
     }
     else {
-	bibtex_struct_destroy (oldstruct, TRUE);
+	bibtex_struct_destroy(oldstruct, TRUE);
     }
 
     g_hash_table_insert (source->table, inskey, value);
